"""konova URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include

from konova.views.logout import LogoutView
from konova.views.geometry import GeomParcelsView, GeomParcelsContentView
from konova.views.home import HomeView
from konova.views.map_proxy import ClientProxyParcelSearch, ClientProxyParcelWFS
from konova.views.oauth import OAuthLoginView, OAuthCallbackView

urlpatterns = [
    path('admin/', admin.site.urls),
    path('oauth/callback/', OAuthCallbackView.as_view(), name="oauth-callback"),
    path('oauth/login/', OAuthLoginView.as_view(), name="oauth-login"),
    path('logout/', LogoutView.as_view(), name="logout"),
    path('', HomeView.as_view(), name="home"),
    path('intervention/', include("intervention.urls")),
    path('compensation/', include("compensation.urls")),
    path('ema/', include("ema.urls")),
    path('user/', include("user.urls")),
    path('news/', include("news.urls")),
    path('cl/', include("codelist.urls")),
    path('analysis/', include("analysis.urls")),
    path('api/', include("api.urls")),
    path('geom/<id>/parcels/', GeomParcelsView.as_view(), name="geometry-parcels"),
    path('geom/<id>/parcels/<int:page>', GeomParcelsContentView.as_view(), name="geometry-parcels-content"),
    path('client/proxy', ClientProxyParcelSearch.as_view(), name="client-proxy-search"),
    path('client/proxy/wfs', ClientProxyParcelWFS.as_view(), name="client-proxy-wfs"),
]

handler400 = "konova.views.error.get_400_view"
handler404 = "konova.views.error.get_404_view"
handler500 = "konova.views.error.get_500_view"
