"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 08.07.21

"""
from django.urls import path

from user.autocomplete.share import ShareUserAutocomplete, ShareTeamAutocomplete
from user.autocomplete.team import TeamAdminAutocomplete
from user.views.api_token import APITokenView, new_api_token_view
from user.views.propagate import PropagateUserView
from user.views.views import *

app_name = "user"
urlpatterns = [
    path("", index_view, name="index"),
    path("propagate/", PropagateUserView.as_view(), name="propagate"),
    path("notifications/", notifications_view, name="notifications"),
    path("token/api", APITokenView.as_view(), name="api-token"),
    path("token/api/new", new_api_token_view, name="api-token-new"),
    path("contact/<id>", contact_view, name="contact"),
    path("team/", index_team_view, name="team-index"),
    path("team/new", new_team_view, name="team-new"),
    path("team/<id>", data_team_view, name="team-data"),
    path("team/<id>/edit", edit_team_view, name="team-edit"),
    path("team/<id>/remove", remove_team_view, name="team-remove"),
    path("team/<id>/leave", leave_team_view, name="team-leave"),

    # Autocomplete urls
    path("atcmplt/share/u", ShareUserAutocomplete.as_view(), name="share-user-autocomplete"),
    path("atcmplt/share/t", ShareTeamAutocomplete.as_view(), name="share-team-autocomplete"),
    path("atcmplt/team/admin", TeamAdminAutocomplete.as_view(), name="team-admin-autocomplete"),
]
